// Copyright 1998-2018 Epic Games, Inc. All Rights Reserved.

#pragma once

#include "UObject/ObjectMacros.h"
#include "AnalyticsSettings.h"
#include "SmartlookSettings.generated.h"

UCLASS()
class USmartlookSettings
	: public UAnalyticsSettingsBase
{
	GENERATED_UCLASS_BODY()

	/** The application (project) specific SDK key, available in your Smartlook dashboard. */
	UPROPERTY(EditAnywhere, Category=Smartlook, meta=(ConfigRestartRequired=false))
	FString SdkKey;

	/** Recorded video frames per second. Higher framerate has more impact on CPU. Recommended setting is 1fps to 5fps. */
	UPROPERTY(EditAnywhere, Category=Smartlook, meta=(ConfigRestartRequired=false))
	int32 Framerate;

	/** Whether to automatically start recording when the game opens. Otherwise you can start recording manually with FAnalytics::Get().GetDefaultConfiguredProvider()->StartSession(); */
	UPROPERTY(EditAnywhere, Category=Smartlook, meta=(ConfigRestartRequired=false))
	bool StartRecording;

// UAnalyticsSettingsBase interface
protected:
	/**
	 * Provides a mechanism to read the section based information into this UObject's properties
	 */
	virtual void ReadConfigSettings();
	/**
	 * Provides a mechanism to save this object's properties to the section based ini values
	 */
	virtual void WriteConfigSettings();
};
