// Copyright 1998-2018 Epic Games, Inc. All Rights Reserved.

#include "SmartlookEditor.h"
#include "SmartlookEditorPrivatePCH.h"
#include "Modules/ModuleManager.h"
#include "SmartlookSettings.h"
#include "Analytics.h"

IMPLEMENT_MODULE( FSmartlookEditorModule, SmartlookEditorModule );

#define LOCTEXT_NAMESPACE "Smartlook"

void FSmartlookEditorModule::StartupModule()
{
}

void FSmartlookEditorModule::ShutdownModule()
{
}

USmartlookSettings::USmartlookSettings(const FObjectInitializer& ObjectInitializer)
	: Super(ObjectInitializer)
{
	SettingsDisplayName = LOCTEXT("SettingsDisplayName", "Smartlook");
	SettingsTooltip = LOCTEXT("SettingsTooltip", "Smartlook configuration settings");
}

void USmartlookSettings::ReadConfigSettings()
{
	SdkKey = FAnalytics::Get().GetConfigValueFromIni(GetIniName(), GetReleaseIniSection(), TEXT("SmartlookSdkKey"), true);
	FString FramerateString = FAnalytics::Get().GetConfigValueFromIni(GetIniName(), GetReleaseIniSection(), TEXT("SmartlookFramerate"), true);
	Framerate = FCString::Atoi(*FramerateString);
	
	FString StartRecordingString = FAnalytics::Get().GetConfigValueFromIni(GetIniName(), GetReleaseIniSection(), TEXT("SmartlookStartRecording"), true);
	StartRecording = StartRecordingString.ToBool();
	
	if (Framerate <= 0) {
		Framerate = 1;
	}
}

void USmartlookSettings::WriteConfigSettings()
{
	FAnalytics::Get().WriteConfigValueToIni(GetIniName(), GetReleaseIniSection(), TEXT("SmartlookSdkKey"), SdkKey);
	
	FString FramerateString = FString::FromInt(Framerate);
	FAnalytics::Get().WriteConfigValueToIni(GetIniName(), GetReleaseIniSection(), TEXT("SmartlookFramerate"), FramerateString);
	
	FString StartRecordingString = FString::FromInt(StartRecording);
	FAnalytics::Get().WriteConfigValueToIni(GetIniName(), GetReleaseIniSection(), TEXT("SmartlookStartRecording"), StartRecordingString);
}

#undef LOCTEXT_NAMESPACE
